Method: Betterlog::Log::Event#format

Defined in:
lib/betterlog/log/event.rb

#format(**args) ⇒ String Also known as: to_s

Formats the log event using the specified formatting options.

This method delegates to an EventFormatter instance to process the log event according to the provided arguments, enabling flexible output generation including JSON representation and pretty-printed strings with optional colorization.

Parameters:

  • A hash of formatting options to control the output format

Returns:

  • The formatted string representation of the log event



152
153
154
# File 'lib/betterlog/log/event.rb', line 152

def format(**args)
  Log::EventFormatter.new(self).format(**args)
end